# About the Notebooks

!!! note
    The documentation for Metador is still under construction.
    The current set of tutorials is not suitable for end-users who
    necessarily need ready-to-use CLI / GUI.
    We will try to provide a set of more end-user oriented tutorials in the future.

**Target Audience:**

Software developers and technically skilled researchers interested in using
Metador for a domain-specific use-case which is not already sufficiently
supported by existing Metador tooling and plugins (such as metadata schemas,
visualization widgets, and dataset packers).

**Prerequisites:**

* basic knowledge of Python (writing scripts, using Jupyter notebooks)
* basic knowledge of `h5py` and `numpy` (creating and inspecting HDF5 files)
* installed `metador-core` package in your environment